@@ -104,7 +104,7 @@ class BasicConfiguration(Configuration, SentryConfigurationMixin, MailConfigurat
     # Build paths inside the project like this: os.path.join(BASE_DIR, ...)
     BASE_DIR = values.PathValue(
         default=os.path.dirname(os.path.dirname(os.path.abspath(__file__))),
-        check_exists=True,
+        check_exists=False,
         environ_prefix='KRYNEGGER'
     )
 
@@ -595,6 +595,8 @@ class Production(Staging):
     DEBUG = False
     CELERY_TASK_ALWAYS_EAGER = False
 
+    SECRET_KEY = values.SecretValue(environ_prefix='KRYNEGGER')
+
     def STATIC_ROOT(self):
         return values.PathValue(
             environ_name='STATIC_ROOT_DIRECTORY',
