@@ -15,11 +15,11 @@ if __name__ == "__main__":
         dotenv_result = load_dotenv(dotenv_path=dotenv_path)
         print('dotenv[manage] configuration %s from "%s"' % ('loaded' if dotenv_result else 'not loaded', dotenv_path))
     except BaseException as e:
-        logging.error('Dotenv file could not loaded')
-        # logging.exception(e)
-        # traceback.print_exc()
-
-    os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION').capitalize())
+        logging.error('dotenv[manage] configuration could not loaded')
+        logging.exception(e)
+        os.environ.setdefault("KRYNEGGER_CONFIGURATION", "development")
+    finally:
+        os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION').capitalize())
 
     try:
         from configurations.management import execute_from_command_line
